@@ -66,7 +66,7 @@ def init_ligand_opt(ligand_df: SettingsDataFrame) -> None:
 
     # Pull from the database; push unoptimized structures
     idx = workflow.from_db(ligand_df, get_mol=True)
-    workflow.to_db(ligand_df, index=idx)
+    workflow.to_db(ligand_df, status='no_opt', index=idx)
     if not ligand_df.settings.optional.ligand.optimize:
         return None
 
@@ -145,6 +145,7 @@ def _start_ligand_jobs_plams(ligand_list: Iterable[Molecule],
         charge_func(s, int(sum(at.properties.get('charge', 0) for at in ligand)))
         ligand.job_geometry_opt(job, s, name='ligand_opt')
         ligand.round_coords()  # `.is_opt = True` is set by `ligand.job_geometry_opt()``
+        allign_axis(ligand)
     return None
 
 
@@ -180,8 +181,13 @@ def optimize_ligand(ligand: Molecule) -> None:
             mol.set_dihed(180.0, anchor, cap_list)
 
     # Find the optimal dihedrals angle between the fragments
-    for bond in bonds:
-        modified_minimum_scan_rdkit(ligand, ligand.get_index(bond))
+    if len(bonds):
+        for bond in bonds:
+            modified_minimum_scan_rdkit(ligand, ligand.get_index(bond))
+    else:
+        rdmol = molkit.to_rdmol(ligand)
+        UFF(rdmol).Minimize()
+        ligand.from_rdmol(rdmol)
 
     # RDKit UFF can sometimes mess up the geometries of carboxylates: fix them
     fix_carboxyl(ligand)
@@ -576,17 +582,23 @@ def modified_minimum_scan_rdkit(ligand: Molecule, bond_tuple: Tuple[int, int]) -
     # Optimize the (constrained) geometry for all dihedral angles in angle_list
     # The geometry that yields the minimum energy is returned
     fixed = _find_idx(mol, bond)
-    for rdmol in rdmol_list:
+    for angle, rdmol in zip(angles, rdmol_list):
+        # Partially relax the geometry to avoid major conformational changes
         ff = UFF(rdmol)
         for f in fixed:
             ff.AddFixedPoint(f)
         ff.Minimize()
 
+        # Fully relax the geometry
+        UFF(rdmol).Minimize()
+
     # Find the conformation with the optimal ligand vector
     cost_list = []
     for rdmol in rdmol_list:
         xyz, idx_rot, idx_trans, idx_angle, angle = _get_allign_args(rdmol,
                                                                      ligand.properties.anchor_tup)
+
+        # Allign with the Cartesian X-axis
         rotmat = optimize_rotmat(xyz, idx_rot)
         xyz = np.matmul(xyz, rotmat.T, out=xyz)
         if angle is not None:
@@ -595,11 +607,12 @@ def modified_minimum_scan_rdkit(ligand: Molecule, bond_tuple: Tuple[int, int]) -
             rotmat2 = axis_rotation_matrix(vec_perp, angle)
             xyz = np.matmul(xyz, rotmat2.T, out=xyz)
         xyz -= xyz[idx_trans]
+
+        # Compute the cost function
         cost = np.exp(xyz[:, 1:]).sum()
         cost_list.append(cost)
 
-    # Perform an unconstrained optimization on the best geometry and update the geometry of ligand
+    # Find and return the ligand with the best geometry
     j = np.argmin(cost_list)
     rdmol_best = rdmol_list[j]
-    UFF(rdmol).Minimize()
     ligand.from_rdmol(rdmol_best)
